@@ -459,24 +459,58 @@ gettingStartedPanel <- function(){
 #' @return \code{downloadsPanel}: Help -> Downloads panel.
 #'
 #' @export
-#'
+  #'
 downloadsPanel<- function(){
-  tabPanel("Example Data",
+  if (.Platform$OS.type == "windows"){
+    tabPanel("Example Data",
       mainPanel(
-    column(10, offset = 0,
-      br(), 
-      h3("Example data sets"),
-      br(), 
-      dataDownloadWidget("RP"),
-      dataDownloadWidget("RPbat"),
-      dataDownloadWidget("cleared"),
-      dataDownloadWidget("powerTower"),
-      dataDownloadWidget("PV"),
-      dataDownloadWidget("trough"),
-      dataDownloadWidget("mock")
+        column(10, offset = 0,
+          br(),
+          h3("Example data sets"),
+          br(),
+          dataDownloadWidget("RP"),
+          dataDownloadWidget("RPbat"),
+          dataDownloadWidget("cleared"),
+          dataDownloadWidget("powerTower"),
+          dataDownloadWidget("PV"),
+          dataDownloadWidget("trough"),
+          dataDownloadWidget("mock"),
+          br(), br(),
+          h5("NOTE: If you are having trouble downloading the example data sets..."),
+          br(),
+          h5("Downloading the zip files in Windows relies on a zip program being
+        in the Windows path statement. If no such program is present, the download
+        will not be successful. However, the examples data sets can be directly
+        loaded into the app by clicking \"Load Data\" and then viewed under the
+        \"Data Input\" tab and analyzed under the \"Analyses\" tab. Templates for
+        formatting the data are also included in the appendices in the User Guide.
+        If you need the .csv's for some other purpose, you can download them via
+        the command line in R. For example, enter
+        write.csv(\"mock$SE\", file = \"NameOfFileToCreate.csv\", row.names = FALSE)
+        to download the SE file for the 'mock' data set. For more information
+        about downloadable example data files, enter ?GenEst from the R command
+        line.")
+        )
+      )
     )
-  )
-  )
+  } else {
+    tabPanel("Example Data",
+      mainPanel(
+        column(10, offset = 0,
+          br(),
+          h3("Example data sets"),
+          br(),
+          dataDownloadWidget("RP"),
+          dataDownloadWidget("RPbat"),
+          dataDownloadWidget("cleared"),
+          dataDownloadWidget("powerTower"),
+          dataDownloadWidget("PV"),
+          dataDownloadWidget("trough"),
+          dataDownloadWidget("mock")
+        )
+      )
+    )
+  }
 }
 
 #' @rdname GenEstUI
