@@ -12,7 +12,7 @@
 #'   "outSEclass", "outSEp", "outSEk", "ltp", "fta", "predsCP", "run_CP",
 #'   "run_CP_clear", "outCPclass", "outCPdist", "outCPl", "outCPs",
 #'   "run_M", "run_M_clear", "split_M", "split_M_clear", "transpose_split",
-#'   "useSSdata", "useSSinputs", "run_g", "run_g_clear", or "outgclass".
+#'   "run_g", "run_g_clear", or "outgclass".
 #'
 #' @param rv Reactive values list for the GenEst GUI.
 #'
@@ -31,8 +31,8 @@ update_input <- function(eventName, rv, input, session){
                     "outSEclass", "outSEp", "outSEk", "ltp", "fta", "predsCP",
                     "run_CP", "run_CP_clear", "outCPclass", "outCPdist",
                     "outCPl", "outCPs", "run_M", "run_M_clear", "split_M",
-                    "split_M_clear", "transpose_split", "useSSdata",
-                    "useSSinputs", "run_g", "run_g_clear", "outgclass",
+                    "split_M_clear", "transpose_split",
+                    "run_g", "run_g_clear", "outgclass",
                     "load_RP", "load_RPbat", "load_cleared", "load_PV",
                     "load_trough", "load_powerTower", "load_mock")
 
@@ -40,26 +40,27 @@ update_input <- function(eventName, rv, input, session){
     stop("eventName missing or not in list of available eventNames")
   }
 
-  if(eventName == "clear_all"){
+  if(eventName == "clear_all" | grepl("load_", eventName)){
     toReset <- c("file_SE", "predsSE", "obsSE", "outSEp", "outSEk",
                  "outSEclass", "DWPCol", "split_SS", "split_CO",
                  "modelChoices_SE1", "outgclass","file_CP", "predsCP", "ltp",
                  "fta", "outCPl", "outCPs", "outCPdist", "outCPclass", 
-                 "modelChoices_CP1", "file_SS", "gSearchInterval",
-                 "gSearchMax", "file_DWP", "file_CO", "COdate")
+                 "modelChoices_CP1", "file_SS", "file_DWP", "file_CO", "COdate",
+                 "sizeCol")
     lapply(toReset, reset)
-
-    scc <- rv$colNames_size
-    if (is.null(scc)){
-      scc <- ""
-    }
-    scs <- rv$sizeCol
-    if (is.null(scc)){
-      scs <- ""
-    }
+#    scc <- rv$colNames_size
+#    if (is.null(scc)){
+#      scc <- ""
+#    }
+#    scs <- rv$sizeCol      # why would the sizeCol not be cleared when all the data sets are?
+#    if (is.null(scc)){
+#      scs <- ""
+#    }
     updateSelectizeInput(session, "predsSE", choices = "")
     updateSelectizeInput(session, "obsSE", choices = "")
-    updateSelectizeInput(session, "class", choices = scc, selected = scs)
+#    updateSelectizeInput(session, "class", choices = scc, selected = scs)
+# NOTE: the commented-out line glued the previous sizes onto the size menu
+    updateSelectizeInput(session, "class", choices = "")
     updateSelectizeInput(session, "modelChoices_SE1", choices = "")
     updateSelectizeInput(session, "split_SS", choices = "")
     updateSelectizeInput(session, "split_CO", choices = "")
@@ -76,15 +77,15 @@ update_input <- function(eventName, rv, input, session){
     updateSelectizeInput(session, "outCPdist", choices = "")
     updateSelectizeInput(session, "outCPclass", choices = "")
     updateSelectizeInput(session, "COdate", choices = "")
-
+    updateNumericInput(session, "gSearchInterval",  value = NULL)
+    updateNumericInput(session, "gSearchMax", value = NULL)
 }
 
   if (eventName == "file_SE"){
     updateSelectizeInput(session, "predsSE", choices = rv$colNames_SE_preds)
     updateSelectizeInput(session, "obsSE", choices = rv$colNames_SE_obs)
     updateSelectizeInput(session, "class", choices = rv$colNames_size,
-      selected = rv$sizeCol
-    )
+      selected = rv$sizeCol)
     updateTabsetPanel(session, "LoadedDataViz", "Searcher Efficiency")
 
     if (rv$nsizeclasses > 1){
@@ -93,7 +94,6 @@ update_input <- function(eventName, rv, input, session){
   }
 
   if (eventName == "file_SE_clear"){
-
     toReset <- c("file_SE", "predsSE", "obsSE", "outSEp", "outSEk",
                  "outSEclass", "DWPCol", "split_SS", "split_CO",
                  "modelChoices_SE1", "outgclass")
@@ -121,8 +121,8 @@ update_input <- function(eventName, rv, input, session){
 
   if (eventName == "file_CP"){
     updateSelectizeInput(session, "predsCP", choices = rv$colNames_CP_preds)
-    updateSelectizeInput(session, "ltp", choices = rv$colNames_CP_ltp)
-    updateSelectizeInput(session, "fta", choices = rv$colNames_CP_fta)
+    updateSelectizeInput(session, "ltp", choices = rv$colNames_ltp)
+    updateSelectizeInput(session, "fta", choices = rv$colNames_fta)
     updateSelectizeInput(session, "class", choices = rv$colNames_size,
       selected = rv$sizeCol
     )
@@ -159,13 +159,16 @@ update_input <- function(eventName, rv, input, session){
   }
 
   if (eventName == "file_SS"){
+    updateNumericInput(session, "gSearchInterval", value = rv$SS[["I"]])
+    updateNumericInput(session, "gSearchMax", value = rv$SS[["span"]])
+    updateSelectizeInput(session, "split_SS", choices = rv$splittable_SS)
     updateTabsetPanel(session, "LoadedDataViz", "Search Schedule")
   }
 
   if (eventName == "file_SS_clear"){
 
     toReset <- c("file_SS", "gSearchInterval", "gSearchMax",
-                 "split_SS", "split_CO", "outgclass")
+      "split_SS", "split_CO", "outgclass")
     lapply(toReset, reset)
 
     updateSelectizeInput(session, "split_SS", choices = "")
@@ -199,13 +202,11 @@ update_input <- function(eventName, rv, input, session){
   if (eventName == "file_CO"){
     updateSelectizeInput(session, "COdate", choices = rv$colNames_COdates)
     if (length(rv$colNames_COdates) == 1){
-      updateSelectizeInput(session, "COdate",
-        choices = rv$colNames_COdates, selected = rv$colNames_COdates
-      )
+      updateSelectizeInput(session, "COdate", choices = rv$colNames_COdates,
+        selected = rv$colNames_COdates)
     }
-    updateSelectizeInput(session, "sizeCol", choices = rv$colNames_size,
-      selected = rv$sizeCol
-    )
+    updateSelectizeInput(session, "class", choices = rv$colNames_size,
+      selected = rv$sizeCol)
     updateTabsetPanel(session, "LoadedDataViz", "Carcass Observations")
   }
 
@@ -230,14 +231,13 @@ update_input <- function(eventName, rv, input, session){
     updateSelectizeInput(session, "predsSE", choices = rv$colNames_SE_preds)
     updateSelectizeInput(session, "obsSE", choices = rv$colNames_SE_obs)
     updateSelectizeInput(session, "class", choices = rv$colNames_size,
-      selected = rv$sizeCol
-    )
+      selected = rv$sizeCol)
+    updateNumericInput(session, "gSearchInterval", value = rv$SS[["I"]])
+    updateNumericInput(session, "gSearchMax", value = rv$SS[["span"]])
     updateSelectizeInput(session, "predsCP", choices = rv$colNames_CP_preds)
-    updateSelectizeInput(session, "ltp", choices = rv$colNames_CP_ltp)
-    updateSelectizeInput(session, "fta", choices = rv$colNames_CP_fta)
-    updateSelectizeInput(session, "class", choices = rv$colNames_size,
-      selected = rv$sizeCol
-    )
+    updateSelectizeInput(session, "ltp", choices = rv$colNames_ltp)
+    updateSelectizeInput(session, "fta", choices = rv$colNames_fta)
+    updateSelectizeInput(session, "class", choices = rv$colNames_size)
     updateSelectizeInput(session, "DWPCol", choices = rv$colNames_DWP)
     if (length(rv$colNames_DWP) == 1){
       updateSelectizeInput(session, "DWPCol", selected = rv$colNames_DWP)
@@ -251,9 +251,10 @@ update_input <- function(eventName, rv, input, session){
         choices = rv$colNames_COdates, selected = rv$colNames_COdates
       )
     }
-    updateSelectizeInput(session, "sizeCol", choices = rv$colNames_size,
+    updateSelectizeInput(session, "class", choices = rv$colNames_size,
       selected = rv$sizeCol
     )
+
     if (rv$nsizeclasses > 1){
       updateSelectizeInput(session, "DWPCol", selected = " ")
     }
@@ -269,8 +270,7 @@ update_input <- function(eventName, rv, input, session){
     toReset <- c(
       "outCPl", "outCPs", "outCPdist", "outsizeclassCP", "modelChoices_CP1",
       "outSEp", "outSEk", "outsizeclassSE", "modelChoices_SE1",
-      "DWPCol", "split_SS", "split_CO",
-      "gSearchInterval", "gSearchMax", "outgclass")
+      "DWPCol", "split_SS", "split_CO", "outgclass")
 
     lapply(toReset, reset)
 
@@ -351,23 +351,19 @@ update_input <- function(eventName, rv, input, session){
     updateSelectizeInput(session, "outSEp", choices = rv$modNames_SEp)
     updateSelectizeInput(session, "outSEk", choices = rv$modNames_SEk)
     updateSelectizeInput(session, "outSEclass", choices = rv$sizeclasses)
-
     updateSelectizeInput(session, "DWPCol", choices = rv$colNames_DWP,
       selected = rv$DWPCol)
     if (length(rv$colNames_DWP) == 1){
       updateSelectizeInput(session, "DWPCol", selected = rv$colNames_DWP)
     }
-
     reset("outgclass")
-    reset("gSearchInterval")
-    reset("gSearchMax")
     updateSelectizeInput(session, "split_SS", choices = "")
     updateSelectizeInput(session, "split_CO", choices = "")
     updateSelectizeInput(session, "outgclass", choices = "")
   }
 
   if (eventName == "run_SE_clear"){
-    toReset <- c("outSEp", "outSEk", "outsizeclassSE", "DWPCol",
+    toReset <- c("outSEp", "outSEk", "outsizeclassSE", #DWPCol,       # reset DWPCol after run_SE_clear?
                  "split_SS", "split_CO", "modelChoices_SE1", "outgclass")
     lapply(toReset, reset)
     updateSelectizeInput(session, "modelChoices_SE1", choices = "")
@@ -385,7 +381,7 @@ update_input <- function(eventName, rv, input, session){
   }
 
   if (eventName == "run_CP"){
-    toReset <- c("outgclass", "gSearchInterval", "gSearchMax")
+    toReset <- c("outgclass")#, "gSearchInterval", "gSearchMax")
     lapply(toReset, reset)
     updateTabsetPanel(session, "analyses_CP", "Model Comparison")
     updateSelectizeInput(session, "outCPl", choices = rv$modNames_CPl)
@@ -399,8 +395,7 @@ update_input <- function(eventName, rv, input, session){
 
   if (eventName == "run_CP_clear"){
     toReset <- c("outCPl", "outCPs", "outCPdist", "outsizeclassCP",
-                 "split_SS", "split_CO", "modelChoices_CP1", "outgclass",
-                 "gSearchInterval", "gSearchMax")
+                 "split_SS", "split_CO", "modelChoices_CP1", "outgclass")
     lapply(toReset, reset)
     updateSelectizeInput(session, "modelChoices_CP1", choices = "")
     updateSelectizeInput(session, "split_SS", choices = "")
@@ -418,13 +413,6 @@ update_input <- function(eventName, rv, input, session){
     updateSelectizeInput(session, "outCPdist", choices = rv$modNames_CPdist)
   }
 
-  if (eventName == "useSSdata"){
-    if (!is.na(rv$SStemp[1])){
-      updateNumericInput(session, "gSearchInterval", value = rv$avgSI)
-      updateNumericInput(session, "gSearchMax", value = max(rv$SS))
-    }
-  }
-
   if (eventName == "run_g"){
     updateSelectizeInput(session, "outgclass", choices = rv$sizeclasses_g)
     updateTabsetPanel(session, "analyses_g", "Summary")
@@ -437,7 +425,7 @@ update_input <- function(eventName, rv, input, session){
 
   if (eventName == "run_M"){
     updateNumericInput(session, "frac", value = rv$frac)
-    updateSelectizeInput(session, "split_SS", choices = rv$colNames_SS_nosel)
+    updateSelectizeInput(session, "split_SS", choices = rv$splittable_SS)
     updateSelectizeInput(session, "split_CO", choices = rv$colNames_CO)
   }
 
@@ -452,7 +440,7 @@ update_input <- function(eventName, rv, input, session){
   if (eventName == "split_M_clear"){
     reset("split_SS")
     reset("split_CO")
-    updateSelectizeInput(session, "split_SS", choices = rv$colNames_SS_nosel)
+    updateSelectizeInput(session, "split_SS", choices = rv$splittable_SS)
     updateSelectizeInput(session, "split_CO", choices = rv$colNames_CO)
   }
 }
