@@ -110,6 +110,7 @@ update_rv <- function(eventName, rv, input){
       rv$sizeCol <- NULL
   }
 
+
   if (eventName == "file_SE_clear"){
     toNULL <- c("data_SE", "filename_SE", "colNames_SE", "colNames_SE_preds",
                 "colNames_SE_preds0", "colNames_SE_obs", "colNames_SE_obs0",
@@ -352,7 +353,7 @@ update_rv <- function(eventName, rv, input){
       if (max(rv$SStemp)%%rv$SStemp[2] == 0){
         rv$SS <- list("span" = max(rv$SStemp), "I" = rv$SStemp[2])
       } else {
-        rv$SS <- list("span" = rv$SStmp[2] * length(rv$SStemp), "I" = rv$SStemp[2])
+        rv$SS <- list("span" = rv$SStemp[2] * length(rv$SStemp), "I" = rv$SStemp[2])
       }
     } else {
       rv$SS <- NULL
@@ -531,6 +532,7 @@ update_rv <- function(eventName, rv, input){
 
     rv$CL <- input$CL
     rv$sizeCol <- input$class
+
     rv$mods_SE <- suppressWarnings(
                     pkmSize(formula_p = rv$formula_p,
                       formula_k = rv$formula_k, data = rv$data_SE,
@@ -891,7 +893,6 @@ update_rv <- function(eventName, rv, input){
     rv$SEmodToUse <- gsub("~ constant", "~ 1", rv$SEmodToUse)
     rv$CPmodToUse <- gsub("~ constant", "~ 1", rv$CPmodToUse)
 
-
     rv$models_SE <- tryCatch(
                       trimSetSize(rv$mods_SE, rv$SEmodToUse),
                       error = function(x){NULL}
@@ -1011,6 +1012,5 @@ update_rv <- function(eventName, rv, input){
       rv$Msplit <- transposeSplits(rv$Msplit)
     }
   }
-
   return(rv)
 }
\ No newline at end of file
